@@ -1,10 +1,10 @@
 from servicefoundry.cli.commands.build_command import get_build_command
 from servicefoundry.cli.commands.create_command import get_create_command
 from servicefoundry.cli.commands.delete_command import get_delete_command
-from servicefoundry.cli.commands.deploy_command import get_deploy_command
+from servicefoundry.cli.commands.deploy_v2_command import deploy_v2_command
 from servicefoundry.cli.commands.get_command import get_get_command
-from servicefoundry.cli.commands.init_command import get_init_command
 from servicefoundry.cli.commands.list_command import get_list_command
 from servicefoundry.cli.commands.login_command import get_login_command
 from servicefoundry.cli.commands.logout_command import get_logout_command
+from servicefoundry.cli.commands.logs_command import get_logs_command
 from servicefoundry.cli.commands.use_command import get_set_command
