@@ -2,7 +2,6 @@ import logging
 
 import rich_click as click
 
-from servicefoundry.cli.config import CliConfig
 from servicefoundry.cli.const import (
     COMMAND_CLS,
     ENABLE_CLUSTER_COMMANDS,
@@ -79,12 +78,10 @@ def create_cluster(name, region, aws_account_id, server_name, ca_data, server_ur
 @click.option("--non-interactive", is_flag=True, default=False)
 @handle_exception_wrapper
 def create_workspace(name, cluster, non_interactive):
-    tail_logs = not CliConfig.get("json")
     workspace = workspace_lib.create_workspace(
         name=name,
         cluster_name_or_id=cluster,
         non_interactive=non_interactive,
-        tail_logs=tail_logs,
     )
     print_obj("Workspace", workspace.to_dict())
 
