@@ -2,6 +2,7 @@ import logging
 
 import rich_click as click
 
+from servicefoundry.cli.config import CliConfig
 from servicefoundry.cli.console import console
 from servicefoundry.cli.const import (
     COMMAND_CLS,
@@ -9,25 +10,18 @@ from servicefoundry.cli.const import (
     ENABLE_SECRETS_COMMANDS,
     GROUP_CLS,
 )
-from servicefoundry.cli.display_util import print_obj
+from servicefoundry.cli.display_util import print_json, print_obj
 from servicefoundry.cli.util import handle_exception_wrapper
 from servicefoundry.lib.clients.service_foundry_client import (
     ServiceFoundryServiceClient,
 )
-from servicefoundry.lib.dao import deployment as deployment_lib
-from servicefoundry.lib.dao import service as service_lib
 from servicefoundry.lib.dao import workspace as workspace_lib
-from servicefoundry.lib.model.entity import (
-    Cluster,
-    Deployment,
-    Secret,
-    SecretGroup,
-    Service,
-    Workspace,
-)
+from servicefoundry.lib.model.entity import Cluster, Secret, SecretGroup, Workspace
 
 logger = logging.getLogger(__name__)
 
+# TODO (chiragjn): --json should disable all non json console prints
+
 
 @click.group(name="get", cls=GROUP_CLS)
 def get_command():
@@ -50,7 +44,10 @@ def get_command():
 def get_cluster(cluster_id):
     tfs_client = ServiceFoundryServiceClient.get_client()
     cluster = tfs_client.get_cluster(cluster_id)
-    print_obj("Cluster", cluster, columns=Cluster.get_display_columns)
+    if CliConfig.get("json"):
+        print_json(data=cluster)
+    else:
+        print_obj("Cluster", cluster, columns=Cluster.get_display_columns)
 
 
 @click.command(name="workspace", cls=COMMAND_CLS, help="Get Workspace metadata")
@@ -70,73 +67,12 @@ def get_workspace(name, cluster, non_interactive):
         cluster_name_or_id=cluster,
         non_interactive=non_interactive,
     )
-    print_obj("Workspace", workspace.to_dict(), columns=Workspace.get_display_columns)
-
-
-@click.command(name="service", cls=COMMAND_CLS, help="Get Service metadata")
-@click.argument("name", type=click.STRING)
-@click.option(
-    "-w",
-    "--workspace",
-    type=click.STRING,
-    default=None,
-    help="workspace to find this service in",
-)
-@click.option(
-    "-c",
-    "--cluster",
-    type=click.STRING,
-    default=None,
-    help="cluster to find this service in",
-)
-@click.option("--non-interactive", is_flag=True, default=False)
-@handle_exception_wrapper
-def get_service(name, workspace, cluster, non_interactive):
-    service = service_lib.get_service(
-        name_or_id=name,
-        workspace_name_or_id=workspace,
-        cluster_name_or_id=cluster,
-        non_interactive=non_interactive,
-    )
-    print_obj("Service", service.to_dict(), columns=Service.get_display_columns)
-
-
-@click.command(name="deployment", cls=COMMAND_CLS, help="Get Deployment metadata")
-@click.argument("name", type=click.STRING)
-@click.option(
-    "-s",
-    "--service",
-    type=click.STRING,
-    default=None,
-    help="service to which the deployment belongs to",
-)
-@click.option(
-    "-w",
-    "--workspace",
-    type=click.STRING,
-    default=None,
-    help="workspace to find this deployment in",
-)
-@click.option(
-    "-c",
-    "--cluster",
-    type=click.STRING,
-    default=None,
-    help="cluster to find this deployment in",
-)
-@click.option("--non-interactive", is_flag=True, default=False)
-@handle_exception_wrapper
-def get_deployment(name, service, workspace, cluster, non_interactive):
-    deployment = deployment_lib.get_deployment(
-        name_or_id=name,
-        service_name_or_id=service,
-        workspace_name_or_id=workspace,
-        cluster_name_or_id=cluster,
-        non_interactive=non_interactive,
-    )
-    print_obj(
-        "Deployment", deployment.to_dict(), columns=Deployment.get_display_columns
-    )
+    if CliConfig.get("json"):
+        print_json(data=workspace.to_dict())
+    else:
+        print_obj(
+            "Workspace", workspace.to_dict(), columns=Workspace.get_display_columns
+        )
 
 
 @click.command(name="secret-group", cls=COMMAND_CLS, help="Get Secret Group")
@@ -163,21 +99,20 @@ def get_current_context():
     tfs_client = ServiceFoundryServiceClient.get_client()
     cluster = tfs_client.session.get_cluster()
     workspace = tfs_client.session.get_workspace()
+    console.print(f"API Server: {tfs_client.session.profile.server_config.api_server}")
     if workspace:
         console.print(f"Workspace: {workspace['name']} ({cluster['id']})")
-    elif cluster:
-        console.print(f"No workspaces set as default ({cluster['id']})")
     else:
         console.print(
-            f"Context not set. Please use `sfy use workspace` to pick a default workspace"
+            f"No workspace set as default. "
+            f"Please use `sfy use workspace` to pick a default workspace"
         )
 
 
 def get_get_command():
     get_command.add_command(get_workspace)
-    get_command.add_command(get_service)
-    get_command.add_command(get_deployment)
     get_command.add_command(get_current_context)
+    # get_command.add_command(get_logs)
 
     if ENABLE_CLUSTER_COMMANDS:
         get_command.add_command(get_cluster)
