@@ -2,6 +2,7 @@ import logging
 
 import rich_click as click
 
+from servicefoundry.cli.config import CliConfig
 from servicefoundry.cli.console import console
 from servicefoundry.cli.const import (
     COMMAND_CLS,
@@ -10,13 +11,12 @@ from servicefoundry.cli.const import (
     ENABLE_SECRETS_COMMANDS,
     GROUP_CLS,
 )
-from servicefoundry.cli.display_util import print_list
+from servicefoundry.cli.display_util import print_json, print_list
 from servicefoundry.cli.util import handle_exception_wrapper
 from servicefoundry.lib.clients.service_foundry_client import (
     ServiceFoundryServiceClient,
 )
 from servicefoundry.lib.dao import deployment as deployment_lib
-from servicefoundry.lib.dao import service as service_lib
 from servicefoundry.lib.dao import workspace as workspace_lib
 from servicefoundry.lib.messages import (
     PROMPT_NO_DEPLOYMENTS,
@@ -25,29 +25,23 @@ from servicefoundry.lib.messages import (
 )
 from servicefoundry.lib.model.entity import (
     Cluster,
-    Deployment,
+    NewDeployment,
     Secret,
     SecretGroup,
-    Service,
     Workspace,
 )
 
 logger = logging.getLogger(__name__)
 
+# TODO (chiragjn): --json should disable all non json console prints
+
 
 @click.group(name="list", cls=GROUP_CLS)
 def list_command():
     # TODO (chiragjn): Figure out a way to update supported resources based on ENABLE_* flags
     """
     Servicefoundry list resources
-
-    \b
-    Supported resources:
-    - workspace
-    - service
-    - deployment
     """
-    pass
 
 
 @click.command(name="cluster", cls=COMMAND_CLS, help="List Clusters")
@@ -55,7 +49,10 @@ def list_command():
 def list_cluster():
     tfs_client = ServiceFoundryServiceClient.get_client()
     clusters = tfs_client.list_cluster()
-    print_list("Clusters", clusters, Cluster.list_display_columns)
+    if CliConfig.get("json"):
+        print_json(data=clusters)
+    else:
+        print_list("Clusters", clusters, Cluster.list_display_columns)
 
 
 @click.command(name="workspace", cls=COMMAND_CLS, help="List Workspaces")
@@ -83,67 +80,41 @@ def list_workspace(all, cluster, non_interactive):
     else:
         workspaces.sort(key=lambda w: (w.fqn, w.createdAt))
     # TODO (chiragjn): Display columns here need to show cluster name!
-    print_list(
-        "Workspaces",
-        [w.to_dict() for w in workspaces],
-        columns=Workspace.list_display_columns,
-    )
-
-
-@click.command(name="service", cls=COMMAND_CLS, help="List Services")
-@click.option("-A", "--all", is_flag=True, default=False)
-@click.option(
-    "-w", "--workspace", type=click.STRING, default=None, help="workspace name"
-)
-@click.option("-c", "--cluster", type=click.STRING, default=None, help="cluster name")
-@click.option("--non-interactive", is_flag=True, default=False)
-@handle_exception_wrapper
-def list_service(all, workspace, cluster, non_interactive):
-    services = service_lib.list_services(
-        workspace_name_or_id=workspace,
-        cluster_name_or_id=cluster,
-        all_=all,
-        non_interactive=non_interactive,
-    )
-    if not services:
-        console.print(PROMPT_NO_SERVICES)
+    workspaces = [w.to_dict() for w in workspaces]
+    if CliConfig.get("json"):
+        print_json(data=workspaces)
     else:
-        services.sort(key=lambda s: (s.fqn, s.name))
-    # TODO (chiragjn): Display columns here need to show workspace and cluster name!
-    print_list(
-        f"Services",
-        [s.to_dict() for s in services],
-        columns=Service.list_display_columns,
-    )
+        print_list(
+            "Workspaces",
+            workspaces,
+            columns=Workspace.list_display_columns,
+        )
 
 
-@click.command(
-    name="deployment", cls=COMMAND_CLS, help="List Deployments for a Service"
-)
-@click.argument("service")
+@click.command(name="deployment", cls=COMMAND_CLS, help="List Deployments")
 @click.option(
-    "-w", "--workspace", type=click.STRING, default=None, help="workspace name"
+    "-w", "--workspace", type=click.STRING, default=None, help="workspace fqn"
 )
-@click.option("-c", "--cluster", type=click.STRING, default=None, help="cluster name")
-@click.option("--non-interactive", is_flag=True, default=False)
 @handle_exception_wrapper
-def list_deployment(service, workspace, cluster, non_interactive):
+def list_deployments(workspace):
     deployments = deployment_lib.list_deployments(
-        service_name_or_id=service,
-        workspace_name_or_id=workspace,
-        cluster_name_or_id=cluster,
-        all_=False,  # TODO (chirajn): Add support for all flag
-        non_interactive=non_interactive,
+        workspace_fqn=workspace,
     )
     if not deployments:
         console.print(PROMPT_NO_DEPLOYMENTS)
     else:
-        deployments.sort(key=lambda d: (d.fqn, d.name))
-    print_list(
-        f"Deployments",
-        [d.to_dict() for d in deployments],
-        columns=Deployment.list_display_columns,
-    )
+        deployments.sort(key=lambda s: (s.fqn))
+
+    deployments = [s.to_dict() for s in deployments]
+    if CliConfig.get("json"):
+        print_json(data=deployments)
+    else:
+        # TODO (chiragjn): Display columns here need to show workspace and cluster name!
+        print_list(
+            "Deployments",
+            deployments,
+            columns=NewDeployment.list_display_columns,
+        )
 
 
 @click.command(name="secret-group", cls=COMMAND_CLS, help="List Secret Groups")
@@ -176,16 +147,15 @@ def list_authorize(resource_type, resource_id):
 
 
 def get_list_command():
-    list_command.add_command(list_workspace)
-    list_command.add_command(list_service)
-    list_command.add_command(list_deployment)
+    # list_command.add_command(list_workspace)
+    list_command.add_command(list_deployments)
 
-    if ENABLE_AUTHORIZE_COMMANDS:
-        list_command.add_command(list_authorize)
-    if ENABLE_CLUSTER_COMMANDS:
-        list_command.add_command(list_cluster)
-    if ENABLE_SECRETS_COMMANDS:
-        list_command.add_command(list_secret)
-        list_command.add_command(list_secret_group)
+    # if ENABLE_AUTHORIZE_COMMANDS:
+    #     list_command.add_command(list_authorize)
+    # if ENABLE_CLUSTER_COMMANDS:
+    #     list_command.add_command(list_cluster)
+    # if ENABLE_SECRETS_COMMANDS:
+    #     list_command.add_command(list_secret)
+    #     list_command.add_command(list_secret_group)
 
     return list_command
