@@ -3,9 +3,9 @@ import logging
 import rich_click as click
 
 from servicefoundry.cli.const import COMMAND_CLS
-from servicefoundry.cli.io.rich_output_callback import RichOutputCallBack
 from servicefoundry.cli.util import handle_exception_wrapper
-from servicefoundry.lib import logout
+from servicefoundry.io.rich_output_callback import RichOutputCallBack
+from servicefoundry.lib.session import logout
 
 logger = logging.getLogger(__name__)
 
