@@ -12,16 +12,22 @@ logger = logging.getLogger(__name__)
 @click.group(name="use", cls=GROUP_CLS)
 def use_command():
     """
-    Set default workspace
+    Set defaults
 
     \b
     Supported resources:
-    - workspace
-    - cluster
+    - server
     """
     pass
 
 
+@click.command(name="server", cls=COMMAND_CLS, help="Set truefoundry server")
+@click.argument("url", type=click.STRING, required=True)
+@handle_exception_wrapper
+def use_server(url):
+    context_lib.use_server(url)
+
+
 @click.command(name="cluster", cls=COMMAND_CLS, help="Set default cluster")
 @click.argument("cluster", type=click.STRING, required=False, default=None)
 @click.option("--non-interactive", is_flag=True, default=False)
@@ -43,6 +49,7 @@ def use_workspace(workspace, non_interactive):
 
 
 def get_set_command():
-    use_command.add_command(use_cluster)
-    use_command.add_command(use_workspace)
+    use_command.add_command(use_server)
+    # use_command.add_command(use_cluster)
+    # use_command.add_command(use_workspace)
     return use_command
