@@ -1,5 +1,5 @@
 class CliConfig:
-    __conf = {"logs": False, "json": False}
+    __conf = {"json": False}
 
     @staticmethod
     def get(name):
