@@ -1,11 +1,18 @@
 import datetime
+import functools
 
-from rich import box, print_json
+from rich import box
+from rich import print_json as _rich_print_json
 from rich.table import Table
 
 from servicefoundry.cli.config import CliConfig
 from servicefoundry.cli.console import console
 from servicefoundry.cli.const import DISPLAY_DATETIME_FORMAT
+from servicefoundry.json_util import json_default_encoder
+
+print_json = functools.partial(
+    _rich_print_json, highlight=False, default=json_default_encoder
+)
 
 
 def get_table(title):
@@ -32,7 +39,8 @@ def print_list(title, items, columns=None):
         if not columns:
             columns = items[0].keys()
         for column in columns:
-            table.add_column(column, justify="left", overflow="fold", no_wrap=False)
+            no_wrap = column in ["id", "fqn"]
+            table.add_column(column, justify="left", overflow="fold", no_wrap=no_wrap)
 
     for item in items:
         row = []
@@ -56,7 +64,8 @@ def print_obj(title, item, columns=None):
     keys, columns = columns, ["key", "value"]
 
     for column in columns:
-        table.add_column(column, justify="left", overflow="fold", no_wrap=False)
+        no_wrap = column in ["id", "fqn"]
+        table.add_column(column, justify="left", overflow="fold", no_wrap=no_wrap)
     for key in keys:
         table.add_row(f"[bold]{stringify(key)}[/]", stringify(item[key]))
     console.print(table)
