@@ -1,4 +1,5 @@
 import functools
+import sys
 import zipfile
 
 import rich_click as click
@@ -20,6 +21,8 @@ def setup_rich_click():
 
 
 def handle_exception(exception):
+    if IS_DEBUG:
+        console.print_exception(show_locals=True)
     if isinstance(exception, BadRequestException):
         print_error(
             f"[cyan bold]status_code[/] {exception.status_code}\n"
@@ -30,10 +33,7 @@ def handle_exception(exception):
     elif isinstance(exception, ConfigurationException):
         print_error(f"[cyan bold]message[/]     {exception.message}")
     else:
-        if IS_DEBUG:
-            console.print_exception()
-        else:
-            console.print(f"[red][bold]Error:[/] {str(exception)}[/]")
+        console.print(f"[red][bold]Error:[/] {str(exception)}[/]")
 
 
 def handle_exception_wrapper(fn):
@@ -43,6 +43,7 @@ def handle_exception_wrapper(fn):
             return fn(*args, **kwargs)
         except Exception as e:
             handle_exception(e)
+            sys.exit(1)
 
     return inner
 
