@@ -1,6 +1,6 @@
-from servicefoundry import lib
 from servicefoundry.core.notebook.notebook_util import get_default_callback
+from servicefoundry.lib import session
 
 
 def logout():
-    lib.logout(output_hook=get_default_callback())
+    session.logout(output_hook=get_default_callback())
