@@ -3,6 +3,7 @@
 
 def is_notebook():
     try:
+        # noinspection PyUnresolvedReferences
         shell = get_ipython().__class__
         if shell.__name__ == "ZMQInteractiveShell":
             return True  # Jupyter notebook or qtconsole
@@ -24,6 +25,6 @@ def get_default_callback():
 
         return NotebookOutputCallBack()
     else:
-        from servicefoundry.io.output_callback import OutputCallBack
+        from servicefoundry.io.rich_output_callback import RichOutputCallBack
 
-        return OutputCallBack()
+        return RichOutputCallBack()
