@@ -15,3 +15,7 @@ class OutputCallBack:
 
     def print_code_in_panel(self, lines, header=None, lang="python"):
         self.print_lines_in_panel(lines, header)
+
+    def print(self, line):
+        # just an alias
+        self.print_line(line)
